==> chaosmesh-model-5.0.1-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/SelectorSpecBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class SelectorSpecBuilder extends SelectorSpecFluentImpl<SelectorSpecBuilder> implements VisitableBuilder<SelectorSpec,SelectorSpecBuilder> {

    SelectorSpecFluent<?> fluent;
    Boolean validationEnabled;

    public SelectorSpecBuilder() {
        this(true);
    }

    public SelectorSpecBuilder(Boolean validationEnabled) {
        this(new SelectorSpec(), validationEnabled);
    }

    public SelectorSpecBuilder(SelectorSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public SelectorSpecBuilder(SelectorSpecFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new SelectorSpec(), validationEnabled);
    }

    public SelectorSpecBuilder(SelectorSpecFluent<?> fluent,SelectorSpec instance) {
        this(fluent, instance, true);
    }

    public SelectorSpecBuilder(SelectorSpecFluent<?> fluent,SelectorSpec instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withAnnotationSelectors(instance.getAnnotationSelectors()); 
        fluent.withFieldSelectors(instance.getFieldSelectors()); 
        fluent.withLabelSelectors(instance.getLabelSelectors()); 
        fluent.withNamespaces(instance.getNamespaces()); 
        fluent.withNodeSelectors(instance.getNodeSelectors()); 
        fluent.withNodes(instance.getNodes()); 
        fluent.withPodPhaseSelectors(instance.getPodPhaseSelectors()); 
        fluent.withPods(instance.getPods()); 
        this.validationEnabled = validationEnabled; 
    }

    public SelectorSpecBuilder(SelectorSpec instance) {
        this(instance,true);
    }

    public SelectorSpecBuilder(SelectorSpec instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withAnnotationSelectors(instance.getAnnotationSelectors()); 
        this.withFieldSelectors(instance.getFieldSelectors()); 
        this.withLabelSelectors(instance.getLabelSelectors()); 
        this.withNamespaces(instance.getNamespaces()); 
        this.withNodeSelectors(instance.getNodeSelectors()); 
        this.withNodes(instance.getNodes()); 
        this.withPodPhaseSelectors(instance.getPodPhaseSelectors()); 
        this.withPods(instance.getPods()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.chaosmesh.v1alpha1.EditableSelectorSpec build() {
        EditableSelectorSpec buildable = new EditableSelectorSpec(fluent.getAnnotationSelectors(),fluent.getFieldSelectors(),fluent.getLabelSelectors(),fluent.getNamespaces(),fluent.getNodeSelectors(),fluent.getNodes(),fluent.getPodPhaseSelectors(),fluent.getPods());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        SelectorSpecBuilder that = (SelectorSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> chaosmesh-model-5.3.2-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/SelectorSpecBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class SelectorSpecBuilder extends SelectorSpecFluentImpl<SelectorSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<SelectorSpec,SelectorSpecBuilder> {

    SelectorSpecFluent<?> fluent;
    Boolean validationEnabled;

    public SelectorSpecBuilder() {
        this(true);
    }

    public SelectorSpecBuilder(Boolean validationEnabled) {
        this(new SelectorSpec(), validationEnabled);
    }

    public SelectorSpecBuilder(SelectorSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public SelectorSpecBuilder(SelectorSpecFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new SelectorSpec(), validationEnabled);
    }

    public SelectorSpecBuilder(SelectorSpecFluent<?> fluent,SelectorSpec instance) {
        this(fluent, instance, true);
    }

    public SelectorSpecBuilder(SelectorSpecFluent<?> fluent,SelectorSpec instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withAnnotationSelectors(instance.getAnnotationSelectors()); 
        fluent.withExpressionSelectors(instance.getExpressionSelectors()); 
        fluent.withFieldSelectors(instance.getFieldSelectors()); 
        fluent.withLabelSelectors(instance.getLabelSelectors()); 
        fluent.withNamespaces(instance.getNamespaces()); 
        fluent.withNodeSelectors(instance.getNodeSelectors()); 
        fluent.withNodes(instance.getNodes()); 
        fluent.withPodPhaseSelectors(instance.getPodPhaseSelectors()); 
        fluent.withPods(instance.getPods()); 
        this.validationEnabled = validationEnabled; 
    }

    public SelectorSpecBuilder(SelectorSpec instance) {
        this(instance,true);
    }

    public SelectorSpecBuilder(SelectorSpec instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withAnnotationSelectors(instance.getAnnotationSelectors()); 
        this.withExpressionSelectors(instance.getExpressionSelectors()); 
        this.withFieldSelectors(instance.getFieldSelectors()); 
        this.withLabelSelectors(instance.getLabelSelectors()); 
        this.withNamespaces(instance.getNamespaces()); 
        this.withNodeSelectors(instance.getNodeSelectors()); 
        this.withNodes(instance.getNodes()); 
        this.withPodPhaseSelectors(instance.getPodPhaseSelectors()); 
        this.withPods(instance.getPods()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.chaosmesh.v1alpha1.EditableSelectorSpec build() {
        EditableSelectorSpec buildable = new EditableSelectorSpec(fluent.getAnnotationSelectors(),fluent.getExpressionSelectors(),fluent.getFieldSelectors(),fluent.getLabelSelectors(),fluent.getNamespaces(),fluent.getNodeSelectors(),fluent.getNodes(),fluent.getPodPhaseSelectors(),fluent.getPods());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        SelectorSpecBuilder that = (SelectorSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
